storytracker
============

Tools for tracking stories on news homepages

[![Build Status](https://travis-ci.org/pastpages/storytracker.svg?branch=master)](https://travis-ci.org/pastpages/storytracker)
[![PyPI version](https://badge.fury.io/py/storytracker.png)](http://badge.fury.io/py/storytracker)
[![Coverage Status](https://coveralls.io/repos/pastpages/storytracker/badge.png?branch=master)](https://coveralls.io/r/pastpages/storytracker?branch=master)

* Documentation [http://storytracker.pastpages.org/](http://storytracker.pastpages.org/)
* Issues: [https://github.com/pastpages/storytracker/issues](<https://github.com/pastpages/storytracker/issues)
* Packaging: [https://pypi.python.org/pypi/storytracker](https://pypi.python.org/pypi/storytracker)
* Testing: [https://travis-ci.org/pastpages/storytracker](https://travis-ci.org/pastpages/storytracker)

Sponsors
--------

[![Reynolds Journalism Institute](http://storytracker.readthedocs.org/en/latest/_static/rji-logo.jpg)](http://www.rjionline.org/)

[![PastPages](https://avatars1.githubusercontent.com/u/1757752?v=2&s=200)](http://www.pastpages.org)
